/************************************************************************************
*                                                                                   *
*   File Name   : output_handler.c                                                  *
*   Contents    : XXXXXXX                                                           *
*   Version     : 1.3                                                               *
*************************************************************************************/ 
#include "sfr_r813.h" 
#include "output_handler.h"

//init after reset
void f_vd_controllerInit(void)
{
    asm("FCLR I");                          /* Interrupt disable */

    /*-----------------------------------------------
    -Change on-chip oscillator clock to Main clock  -
    -------------------------------------------------*/
    prc0 = 1;                               /* Protect off */
    cm13 = 1;                               /* Xin Xout */
    cm15 = 1;                               /* XCIN-XCOUT drive capacity select bit : HIGH */
    cm05 = 0;                               /* Xin on */
    cm16 = 0;                               /* Main clock = No division mode */
    cm17 = 0;
    cm06 = 0;                               /* CM16 and CM17 enable */
    asm("nop");                             /* Waiting for stable of oscillation */
    asm("nop");
    asm("nop");
    asm("nop");
    ocd2 = 0;                               /* Main clock change */
    prc0 = 0;                               /* Protect on */

    /* Setting GPIO port direction registers */
    prc2 = 1;
	pd0_1 = 1;                              /* P0.1 = Output */
    prc2 = 1;
	pd0_2 = 1;                              /* P0.2 = Output */
    prc2 = 1;
	pd0_3 = 1;                              /* P0.3 = Output */
    prc2 = 1;
	pd0_4 = 1;                              /* P0.4 = Output */
    prc2 = 1;
	pd0_5 = 1;                              /* P0.5 = Output */
	prc2 = 0;

    pd1_0 = 1;                              /* P1.0 = Output */
    pd1_1 = 1;                              /* P1.1 = Output */
    pd1_2 = 1;                              /* P1.2 = Output */
    pd1_3 = 1;                              /* P1.3 = Output */
    pd1_6 = 1;                              /* P1.6 = Output */

    pd3_0 = 1;                              /* P3.0 = Output */
	txocnt = 0;
	tcout3 = 0;
    pd3_3 = 1;                              /* P3.3 = Output */


    /*-----------------------------------
    -   Initialize SFR                  -
    -----------------------------------*/
    
	f_vd_TIMERX_init();                   /* Initial setting of TIMER X registers */

	f_vd_UART0_init();		      /* Initial setting of UART0 registers */

	f_vd_EXTINTS_init();		      /* Initial setting of EXTINT registers */

        f_vd_adcInit();

    asm("FSET I");                            /* Interrupt enable */

}


//function is called every 1ms and sets or resets 1 segment at 1 display
void f_vd_outputHandler(unsigned long content_to_display)
{
static unsigned int ui_outputHandlerState;

switch (ui_outputHandlerState)
{
	//undefined
	case d_undefinedHandlerState:
		ui_outputHandlerState = d_Disp1_SegA;
		break;
	//display 1
	case d_Disp1_SegA:	
		if (content_to_display & d_value_mask_disp1 & (0x01 * d_bitmask_segA))
		{
			Set_D1_SegA;
		}
		else
		{
			Reset_D1_AllSegs;
		}
		ui_outputHandlerState = d_Disp1_SegB;
		break;	
	case d_Disp1_SegB:	
		if (content_to_display & d_value_mask_disp1 & (0x01 * d_bitmask_segB))
		{
			Set_D1_SegB;
		}
		else
		{
			Reset_D1_AllSegs;
		}
		ui_outputHandlerState = d_Disp1_SegC;
		break;			
	case d_Disp1_SegC:	
		if (content_to_display & d_value_mask_disp1 & (0x01 * d_bitmask_segC))
		{
			Set_D1_SegC;
		}
		else
		{
			Reset_D1_AllSegs;
		}
		ui_outputHandlerState = d_Disp1_SegD;
		break;			
	case d_Disp1_SegD:	
		if (content_to_display & d_value_mask_disp1 & (0x01 * d_bitmask_segD))
		{
			Set_D1_SegD;
		}
		else
		{
			Reset_D1_AllSegs;
		}
		ui_outputHandlerState = d_Disp1_SegE;
		break;			
	case d_Disp1_SegE:	
		if (content_to_display & d_value_mask_disp1 & (0x01 * d_bitmask_segE))
		{
			Set_D1_SegE;
		}
		else
		{
			Reset_D1_AllSegs;
		}
		ui_outputHandlerState = d_Disp1_SegF;
		break;			
	case d_Disp1_SegF:	
		if (content_to_display & d_value_mask_disp1 & (0x01 * d_bitmask_segF))
		{
			Set_D1_SegF;
		}
		else
		{
			Reset_D1_AllSegs;
		}
		ui_outputHandlerState = d_Disp1_SegG;
		break;			
	case d_Disp1_SegG:	
		if (content_to_display & d_value_mask_disp1 & (0x01 * d_bitmask_segG))
		{
			Set_D1_SegG;
		}
		else
		{
			Reset_D1_AllSegs;
		}
		ui_outputHandlerState = d_Disp2_SegA;
		break;			
	//display 2
	case d_Disp2_SegA:	
		if (content_to_display & d_value_mask_disp2 & (0x0100 * d_bitmask_segA))
		{
			Set_D2_SegA;
		}
		else
		{
			Reset_D2_AllSegs;
		}
		ui_outputHandlerState = d_Disp2_SegB;
		break;	
	case d_Disp2_SegB:	
		if (content_to_display & d_value_mask_disp2 & (0x0100 * d_bitmask_segB))
		{
			Set_D2_SegB;
		}
		else
		{
			Reset_D2_AllSegs;
		}
		ui_outputHandlerState = d_Disp2_SegC;
		break;			
	case d_Disp2_SegC:	
		if (content_to_display & d_value_mask_disp2 & (0x0100 * d_bitmask_segC))
		{
			Set_D2_SegC;
		}
		else
		{
			Reset_D2_AllSegs;
		}
		ui_outputHandlerState = d_Disp2_SegD;
		break;			
	case d_Disp2_SegD:
        if (content_to_display & d_value_mask_disp2 & (0x0100 * d_bitmask_segD))
		{
			Set_D2_SegD;
		}
		else
		{
			Reset_D2_AllSegs;
		}	
		ui_outputHandlerState = d_Disp2_SegE;
		break;			
	case d_Disp2_SegE:
        if (content_to_display & d_value_mask_disp2 & (0x0100 * d_bitmask_segE))
		{
			Set_D2_SegE;
		}
		else
		{
			Reset_D2_AllSegs;
		}	
		ui_outputHandlerState = d_Disp2_SegF;
		break;			
	case d_Disp2_SegF:
		if (content_to_display & d_value_mask_disp2 & (0x0100 * d_bitmask_segF))
		{
			Set_D2_SegF;
		}
		else
		{
			Reset_D2_AllSegs;
		}
		ui_outputHandlerState = d_Disp2_SegG;
		break;			
	case d_Disp2_SegG:
		if (content_to_display & d_value_mask_disp2 & (0x0100 * d_bitmask_segG))
		{
			Set_D2_SegG;
		}
		else
		{
			Reset_D2_AllSegs;
		}
		ui_outputHandlerState = d_Disp3_SegA;
		break;					
	//display 3
	case d_Disp3_SegA:
		if (content_to_display & d_value_mask_disp3 & (0x010000 * d_bitmask_segA))
		{
			Set_D3_SegA;
		}
		else
		{
			Reset_D3_AllSegs;
		}
		ui_outputHandlerState = d_Disp3_SegB;
		break;	
	case d_Disp3_SegB:	
		if (content_to_display & d_value_mask_disp3 & (0x010000 * d_bitmask_segB))
		{
			Set_D3_SegB;
		}
		else
		{
			Reset_D3_AllSegs;
		}
		ui_outputHandlerState = d_Disp3_SegC;
		break;			
	case d_Disp3_SegC:
		if (content_to_display & d_value_mask_disp3 & (0x010000 * d_bitmask_segC))
		{
			Set_D3_SegC;
		}
		else
		{
			Reset_D3_AllSegs;
		}
		ui_outputHandlerState = d_Disp3_SegD;
		break;			
	case d_Disp3_SegD:	
		if (content_to_display & d_value_mask_disp3 & (0x010000 * d_bitmask_segD))
		{
			Set_D3_SegD;
		}
		else
		{
			Reset_D3_AllSegs;
		}
		ui_outputHandlerState = d_Disp3_SegE;
		break;			
	case d_Disp3_SegE:
		if (content_to_display & d_value_mask_disp3 & (0x010000 * d_bitmask_segE))
		{
			Set_D3_SegE;
		}
		else
		{
			Reset_D3_AllSegs;
		}
		ui_outputHandlerState = d_Disp3_SegF;
		break;			
	case d_Disp3_SegF:
		if (content_to_display & d_value_mask_disp3 & (0x010000 * d_bitmask_segF))
		{
			Set_D3_SegF;
		}
		else
		{
			Reset_D3_AllSegs;
		}
		ui_outputHandlerState = d_Disp3_SegG;
		break;			
	case d_Disp3_SegG:	
		if (content_to_display & d_value_mask_disp3 & (0x010000 * d_bitmask_segG))
		{
			Set_D3_SegG;
		}
		else
		{
			Reset_D3_AllSegs;
		}
		ui_outputHandlerState = d_Disp4_SegA;
		break;	
	//display 4
	case d_Disp4_SegA:
		if (content_to_display & d_value_mask_disp4 & (0x01000000 * d_bitmask_segA))
		{
			Set_D4_SegA;
		}
		else
		{
			Reset_D4_AllSegs;
		}
		ui_outputHandlerState = d_Disp4_SegB;
		break;	
	case d_Disp4_SegB:	
		if (content_to_display & d_value_mask_disp4 & (0x01000000 * d_bitmask_segB))
		{
			Set_D4_SegB;
		}
		else
		{
			Reset_D4_AllSegs;
		}
		ui_outputHandlerState = d_Disp4_SegC;
		break;			
	case d_Disp4_SegC:
		if (content_to_display & d_value_mask_disp4 & (0x01000000 * d_bitmask_segC))
		{
			Set_D4_SegC;
		}
		else
		{
			Reset_D4_AllSegs;
		}
		ui_outputHandlerState = d_Disp4_SegD;
		break;			
	case d_Disp4_SegD:
		if (content_to_display & d_value_mask_disp4 & (0x01000000 * d_bitmask_segD))
		{
			Set_D4_SegD;
		}
		else
		{
			Reset_D4_AllSegs;
		}
		ui_outputHandlerState = d_Disp4_SegE;
		break;			
	case d_Disp4_SegE:
		if (content_to_display & d_value_mask_disp4 & (0x01000000 * d_bitmask_segE))
		{
			Set_D4_SegE;
		}
		else
		{
			Reset_D4_AllSegs;
		}
		ui_outputHandlerState = d_Disp4_SegF;
		break;			
	case d_Disp4_SegF:
		if (content_to_display & d_value_mask_disp4 & (0x01000000 * d_bitmask_segF))
		{
			Set_D4_SegF;
		}
		else
		{
			Reset_D4_AllSegs;
		}
		ui_outputHandlerState = d_Disp4_SegG;
		break;			
	case d_Disp4_SegG:	
		if (content_to_display & d_value_mask_disp4 & (0x01000000 * d_bitmask_segG))
		{
			Set_D4_SegG;
		}
		else
		{
			Reset_D4_AllSegs;
		}
		ui_outputHandlerState = d_Disp1_SegA;
		break;	
}

}
