/************************************************************************************
*                                                                                   *
*   File Name   : timer_irq.c                                                       *
*   Contents    : Timer X related functions of the Match Display                    *
*   Version     : 1.4                                                               *
*************************************************************************************/ 
#include "sfr_r813.h"                       /* Definition of the R8C/10 SFR */
#include "output_handler.h"
#include "globals.h"

/************************************************************************************
Name:        TIMERX_init
Parameters:  None
Returns:     None
Description: Initial setting of Timer X registers
************************************************************************************/
void f_vd_TIMERX_init(void)
{
    txck0 = 0;                              /* Timer X count source = f1 */
    txck1 = 0;

    /* Setting the main cycle timer                   */
    /* 20 MHz * 1/32 * 1/25 * 1/25 => 100 Hz = 1ms  */
    prex = 25-1;                            /* Setting Prescaler X register */
    tx   = 25-1;                           /* Setting timer X register */

    txck0	= 0;                     		/* Timer Count source = f32 */
    txck1	= 1;
	
    txmr = 0x00;                            /* Timer X : timer mode */
    txic = 5;                               /* Interrupt priority level = 5 */

    ir_txic = 0;                            /* Interrupt request flag clear */
    txs  = 1;                               /* Timer X count start flag = start */
}
/************************************************************************************
Name:        interrupt Timer X
Parameters:  None
Returns:     None
Description: Timer X
************************************************************************************/
#pragma interrupt timer_1ms_irq
void timer_1ms_irq(void)
{
	//disable all IRQ's
	UI_TIRQ_count1ms++;                            /* 1 msecond counter increment */
	//toggle LED all 1000ms
	if ( (UI_TIRQ_count1ms%1000) == 0 )           /* 1 second have passed ? */
    	{
        	ActLED_port = ~ActLED_port;
			//f_vd_sendValues(); /* send debug values on serial interface */
	}
	//trigger ADC's all 100ms
	if ( (UI_TIRQ_count1ms%100) == 0 )           /* 0.1 second have passed ? */
    	{
        	f_vd_AcquireVoltages();
	}
	//update LED-digits all 1ms
	f_vd_outputHandler(UL_DISP_CODE);
	//enable all IRQ's
}
