/************************************************************************************
*                                                                                   *
*   File Name   : uart_functions.c                                                  *
*   Contents    : UART-related functions for the Match Display                      *
*   Version     : 1.1                                                               *
*************************************************************************************/ 
#include "sfr_r813.h"                       /* Definition of the R8C/10 SFR */
#include "output_handler.h"

/************************************************************************************
Name:        sendTxd0
Parameters:  unsigned char data - byte to be send via UART0
Returns:     None
Description: Initial setting of UART0 registers
************************************************************************************/
void f_vd_sendTxd0(unsigned char data)
{
	while (ti_u0c1 == 0);
	u0tbl = data;
	te_u0c1 = 1;
}

/************************************************************************************
Name:        UART0_init
Parameters:  None
Returns:     None
Description: Initial setting of UART0 registers
************************************************************************************/
void f_vd_UART0_init(void)
{
        pd1_4 = 1;                              /* P1.4 = TxD Output */
        pd1_5 = 0;                              /* P1.5 = RxD Input */
	u0mr = 0x05;
	u0c0 = 0x00;
	u0rrm = 0;
	u0brg = 130-1;
	ilvl0_s0ric = 0;
	ilvl1_s0ric = 0;
	ilvl2_s0ric = 1; /* interrupt prio 4 */	
	re_u0c1 = 1;
	ir_s0ric = 0; /* clear reception flag */
}

/************************************************************************************
Name:        sendValues
Parameters:  None
Returns:     None
Description: send values on UART0
************************************************************************************/
void f_vd_sendValues(void)
{
unsigned int  value;
unsigned char digit;

f_vd_sendTxd0('s'); /* send start character 's' */

f_vd_sendTxd0('C');
f_vd_sendTxd0('H');
f_vd_sendTxd0('G');
f_vd_sendTxd0(':');
digit = UI_CHARGER_VOLTAGE_AD/10000;
f_vd_sendTxd0(0x30+digit);
value = UI_CHARGER_VOLTAGE_AD - (digit*10000);
digit = value/1000;
f_vd_sendTxd0(0x30+digit);
value = value - (digit*1000);
digit = value/100;
f_vd_sendTxd0(0x30+digit);
value = value - (digit*100);
digit = value/10;
f_vd_sendTxd0(0x30+digit);
value = value - (digit*10);
digit = value/1;
f_vd_sendTxd0(0x30+digit);

f_vd_sendTxd0('|');

f_vd_sendTxd0('B');
f_vd_sendTxd0('A');
f_vd_sendTxd0('T');
f_vd_sendTxd0(':');
digit = UI_BATTERY_VOLTAGE_AD/10000;
f_vd_sendTxd0(0x30+digit);
value = UI_BATTERY_VOLTAGE_AD - (digit*10000);
digit = value/1000;
f_vd_sendTxd0(0x30+digit);
value = value - (digit*1000);
digit = value/100;
f_vd_sendTxd0(0x30+digit);
value = value - (digit*100);
digit = value/10;
f_vd_sendTxd0(0x30+digit);
value = value - (digit*10);
digit = value/1;
f_vd_sendTxd0(0x30+digit);


f_vd_sendTxd0('e'); /* send end character 'e' */
}
/***********************************************************************************/
